@@ -284,7 +284,28 @@ class RKXMLRequest(XMLRequest):
                         cook_mins=(item.attrib['CookMins']), modi_weight=(item.attrib['ModiWeight']),
                         min_rest_qnt=(item.attrib['MinRestQnt']), categ_path=(item.attrib['CategPath']),
                         price_mode=(item.attrib['PriceMode']), modi_scheme=(item.attrib['ModiScheme']),
-                        combo_scheme=(item.attrib['ComboScheme'])
+                        combo_scheme=(item.attrib['ComboScheme']), kurs=(item.attrib['Kurs']),
+                        qnt_dec_digits=(item.attrib['QntDecDigits']), comment=(item.attrib['Comment']),
+                        instruct=(item.attrib['Instruct']), flags=(item.attrib['Flags']),
+                        tara_weight=(item.attrib['TaraWeight']), confirm_qnt=(item.attrib['ConfirmQnt']),
+                        bar_codes=(item.attrib['BarCodes']), open_price=(item.attrib['OpenPrice']),
+                        change_qnt_once=(item.attrib['ChangeQntOnce']),
+                        use_rest_control=(item.attrib['UseRestControl']),
+                        use_confirm_qnt=(item.attrib['UseConfirmQnt']),
+                        bar_codes_full_info=(item.attrib['BarcodesFullInfo']),
+                        item_kind=(item.attrib['ItemKind']),
+                        tariff_round_rule=(item.attrib['TariffRoundRule']),
+                        combo_discount=(item.attrib['ComboDiscount']),
+                        money_round_rule=(item.attrib['MoneyRoundRule']), round_time=(item.attrib['RoundTime']),
+                        guests_dish_rating=(item.attrib['GuestsDishRating']), rate_type=(item.attrib['RateType']),
+                        right_lvl=(item.attrib['RightLvl']),
+                        minimum_tarif_time=(item.attrib['MinimumTarifTime']),
+                        maximum_tarif_time=(item.attrib['MaximumTarifTime']),
+                        ignored_tarif_time=(item.attrib['IgnoredTarifTime']),
+                        min_tarif_amount=(item.attrib['MinTarifAmount']),
+                        max_tarif_amount=(item.attrib['MaxTarifAmount']),
+                        availability_schedule=(item.attrib['AvailabilitySchedule']),
+                        dont_pack=(item.attrib['DontPack'])
                     )
                     element.append(menu_items_dto)
         except Exception as error:
